@@ -6,7 +6,6 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include <KCModule>
 
 #include <QVariant>
@@ -21,11 +20,7 @@ class KCMAkregatorAdvancedConfig : public KCModule
     Q_OBJECT
 
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMAkregatorAdvancedConfig(QWidget *parent, const QVariantList &args);
-#else
-    explicit KCMAkregatorAdvancedConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
+    explicit KCMAkregatorAdvancedConfig(QObject *parent, const KPluginMetaData &data);
 
     void load() override;
     void save() override;
