@@ -8,10 +8,6 @@
 #pragma once
 
 #include <KCModule>
-#include <QVariant>
-
-#include "akregatorconfig.h"
-
 class QButtonGroup;
 
 class KCMAkregatorArchiveConfig : public KCModule
@@ -29,5 +25,5 @@ public:
 
 private:
     QWidget *const m_widget;
-    QButtonGroup *m_archiveModeGroup = nullptr;
+    QButtonGroup *const m_archiveModeGroup;
 };
