@@ -46,7 +46,7 @@ void Frame::slotSetCaption(const QString &s)
 void Frame::slotSetStatusText(const QString &s)
 {
     m_statusText = s;
-    m_statusText = Akregator::Utils::stripTags(m_statusText);
+    m_statusText = Utils::stripTags(m_statusText);
     Q_EMIT signalStatusText(this, m_statusText);
 }
 
@@ -137,7 +137,7 @@ void Frame::slotSetStarted()
         m_progressId = KPIM::ProgressManager::getUniqueID();
     }
     m_progressItem = KPIM::ProgressManager::createProgressItem(m_progressId, title(), QString(), false);
-    m_progressItem->setStatus(i18n("Loading..."));
+    m_progressItem->setStatus(i18n("Loading…"));
     m_state = Started;
     Q_EMIT signalStarted(this);
 }
